@@ -1,7 +1,7 @@
 """
 Type annotations for sagemaker-a2i-runtime service client paginators.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/paginators.html)
+[Open documentation](./paginators.md)
 
 Usage::
 
@@ -23,18 +23,15 @@ from typing import Iterator
 
 from botocore.paginate import Paginator as Boto3Paginator
 
-from mypy_boto3_sagemaker_a2i_runtime.literals import SortOrder
-from mypy_boto3_sagemaker_a2i_runtime.type_defs import (
-    ListHumanLoopsResponseTypeDef,
-    PaginatorConfigTypeDef,
-)
+from .literals import SortOrder
+from .type_defs import ListHumanLoopsResponseTypeDef, PaginatorConfigTypeDef
 
 __all__ = ("ListHumanLoopsPaginator",)
 
 
 class ListHumanLoopsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/paginators.html#listhumanloopspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops)[Show boto3-stubs documentation](./paginators.md#listhumanloopspaginator)
     """
 
     def paginate(
@@ -46,6 +43,6 @@ class ListHumanLoopsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListHumanLoopsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops.paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/paginators.html#listhumanloopspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops.paginate)
+        [Show boto3-stubs documentation](./paginators.md#listhumanloopspaginator)
         """
